function [s,s_dot,p,c] = DSFLocUknPropSpdStnySrc_SclgConf(S,S_dot,P,C,N,kk)
% function [s,s_dot,p,c] = DSFLocUknPropSpdStnySrc_SclgConf(S,S_dot,P,C,N,kk)
%
% Selection of configurations for stationary source localization by frequency
% measurements when signal propagation speed is not known.  It is
% to guarantee valid Doppler frequency measurements.
%
% Input:
%   S:        (2 x 12 x KK), a collection of sensor positions for KK configurations
%   S_dot:    (2 x 12 x KK), a collection of sensor velocities for KK configurations
%   P:        (2 x 1 x KK), a collection of source positions for KK configurations
%   C:        (1 x 1 x KK), a collection of signal propagation speeds for KK configurations
%   N:        (1 x 1), the number of sensors
%   kk:       (1 x 1), the kk-th configuration
%
% Output:
%   s:       (2 x N), the sensor positions for the kk-th configuration
%   s_dot:   (2 x N), the sensor velocities for the kk-th configuration
%   p:     (2 x 1), the source position for the kk-th configuration
%   c:     (1 x 1), the signal propagation speed for the kk-th configuration
%
% Reference:
% D. Lin, G. Wang, K. C. Ho, and L. Huang, "Source localization by frequency
% measurements in unknown signal propagation speed environments," IEEE
% Trans. Aerosp. Electron. Syst.,vol. 59, no. 4, pp. 3953-3970, Aug. 2023.
%
% Danyan Lin, Gang Wang, K. C. Ho	Nov. 1, 2023
%
%       Copyright (C) 2023
%       the Faculty of Electrical Engineering and Computer Science
%       Ningbo University
%       Ningbo 315211, China
%       wanggang@nbu.edu.cn
%

s = S(:,1:N,kk);
ss_dot = [];
for i = 1:12
    if abs(S_dot(1,i,kk))>=1e-3&&abs(S_dot(2,i,kk))>=1e-3
        ss_dot = [ss_dot,S_dot(:,i,kk)];
    end
end
s_dot = ss_dot(:,1:N);
p = P(:,:,kk);
c = C(kk);%km/s
end